pub struct StructField {
pub name: Option<String>,
pub type_decl: TypeDecl,
pub docs: Vec<String>,
pub annotations: Vec<Annotation>,
}Expand description
Field of a struct or of an enum variant payload.
name is None for tuple-like structs / variants; otherwise it stores the
field identifier from IDL. Each field keeps its own documentation and annotations.
Fields
name: Option<String>type_decl: TypeDecldocs: Vec<String>annotations: Vec<Annotation>Trait Implementations
Sourceimpl Clone for StructField
impl Clone for StructField
Sourcefn clone(&self) -> StructField
fn clone(&self) -> StructField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructField
impl Debug for StructField
Sourceimpl PartialEq for StructField
impl PartialEq for StructField
Sourcefn eq(&self, other: &StructField) -> bool
fn eq(&self, other: &StructField) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StructField