pub struct ServiceUnit {
pub name: ServiceIdent,
pub extends: Vec<ServiceIdent>,
pub funcs: Vec<ServiceFunc>,
pub events: Vec<ServiceEvent>,
pub types: Vec<Type>,
pub docs: Vec<String>,
pub annotations: Vec<Annotation>,
}Expand description
AST node describing a service definition.
A service is an interface that:
- may
extendsother services, inheriting their events, functions and types, - defines
funcsinfunctions { ... }, - defines
eventsinevents { ... }, - defines service-local
types { ... }, - may contain documentation comments and annotations.
Fields
name: ServiceIdentextends: Vec<ServiceIdent>funcs: Vec<ServiceFunc>events: Vec<ServiceEvent>types: Vec<Type>docs: Vec<String>annotations: Vec<Annotation>Implementations
Sourceimpl ServiceUnit
impl ServiceUnit
Sourcepub fn interface_id(&self) -> Result<InterfaceId, String>
pub fn interface_id(&self) -> Result<InterfaceId, String>
Compute a deterministic interface identifier for this service.
The hash incorporates:
- all functions (kind, name, params, output, optional throws),
- all events (their payload shape),
- all base services by their already-computed interface IDs.
Types referenced by functions or events are expanded via the AST
definitions in self.types, including generic instantiation.
Sourceimpl ServiceUnit
impl ServiceUnit
Sourcepub fn normalize(&mut self)
pub fn normalize(&mut self)
Stabilize ordering for deterministic output and comparisons.
Also computes entry_id for each func and event from @entry_id annotation,
falling back to declaration-order index.
Sourcepub fn is_partial(&self) -> bool
pub fn is_partial(&self) -> bool
Returns true if the service is annotated with @partial.
Partial services describe a subset of an existing on-chain service and require
explicit @entry_id annotations on all functions and events.